# coding=utf-8
import json
import httpx
from jinja2 import Template
from nonebot.params import CommandArg
from nonebot.adapters import Message
from nonebot import on_command

from .basicinformation import get_basic_information
from .judgmentrolename import judgment_role_name
from .itemlink import get_link
from .pil_draw.draw import draw_main
from .util import UniMessage, get_template, get_html,template_to_pic
from .config import plugin_config

echo_cards = on_command("鸣潮共鸣链查询")

html_spath = get_template("echolink")

headers = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/125.0.0.0 Safari/537.36 Edg/125.0.0.0',
    'Referer': 'https://wiki.kurobbs.com/',
    'Upgrade-Insecure-Requests': '1',
    'Sec-Ch-Ua-Platform': '"Windows"',
    'Sec-Ch-Ua': '"Microsoft Edge";v="125", "Chromium";v="125", "Not=A?Brand";v="24"',
    'Sec-Ch-Ua-Mobile': '?0',
    'Wiki_type': '9'

}
listdata = {
    'catalogueId': '1105',
    'page': '1',
    'limit': '1000'
}


@echo_cards.handle()
async def ehco_card_handle(args: Message = CommandArg()):
    role_name = judgment_role_name(args.extract_plain_text())
    role_id = await get_link(role_name, listdata)
    if role_id is None:
        await echo_cards.finish(f'没有找到角色,错误参数：' + role_name)
    else:
        async with httpx.AsyncClient() as client:
            roledata = {
                'id': role_id
            }
            roledataurl = 'https://api.kurobbs.com/wiki/core/catalogue/item/getEntryDetail'
            roledata_r = await client.post(roledataurl, data=roledata, headers=headers)
            data = json.loads(roledata_r.text)

            info_data = get_basic_information(data)
            content_data = data.get('data').get('content').get('modules')[1].get('components')[1].get('content')
            content = await get_html(content_data)

            Data = {
                'roleimg': info_data.get('role_img'),
                'roleenname': info_data.get('role_en_name'),
                'rolename': info_data.get('role_name'),
                'campIcon': info_data.get('campIcon'),
                'roledescription': info_data.get('role_description'),
                'roledescriptiontitle': info_data.get('role_description_title'),
                'content': content,
            }

            if plugin_config.makeimg_mode == 'htmltopic':
                img = await template_to_pic(
                    html_spath.parent.as_posix(),
                    html_spath.name,
                    Data,
                )
            elif plugin_config.makeimg_mode == 'piltopic':
                img = await draw_main(
                    Data,
                    html_spath.name,
                    html_spath.parent.as_posix(),
                )

        await UniMessage.image(raw=img).finish()
